@@ -75,6 +75,9 @@ class BrowserV2:
     def switch_to_frame(self, frame):
         self.driver.switch_to.frame(frame)
 
+    def screenshot(self, xpath, filename):
+        return self.driver.find_element(By.XPATH, xpath).screenshot(filename)
+
     def get_href(self, xpath):
         return self.driver.find_element(By.XPATH, xpath).get_attribute('href')
 
